- `00_preprocess_MIMICIII.ipynb`: Create dataset for predicting Glasgow Coma Scale based on MIMIC-III database
- `run_experiments.sh`: Run all experiments for Table 1 and 2 in the paper
- `./out`: Output of `run_experiments.sh`